DeleteMarkerEntry class

Information about the delete marker.

Constructors

DeleteMarkerEntry(bool? isLatest, String? key, DateTime? lastModified, Owner? owner, String? versionId)
DeleteMarkerEntry.fromXml(XmlElement xml)

Properties

hashCode int
The hash code for this object.
no setterinherited
isLatest bool?
getter/setter pair
key String?
getter/setter pair
lastModified DateTime?
getter/setter pair
owner Owner?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
versionId String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toXml() → XmlNode

Operators

operator ==(Object other) bool
The equality operator.
inherited