DeletedObject class

Information about the deleted object.

Constructors

DeletedObject(bool? deleteMarker, String? deleteMarkerVersionId, String? key, String? versionId)
DeletedObject.fromXml(XmlElement xml)

Properties

deleteMarker bool?
getter/setter pair
deleteMarkerVersionId String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
key String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
versionId String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toXml() → XmlNode

Operators

operator ==(Object other) bool
The equality operator.
inherited