noncurrentDays property
Specifies the number of days an object is noncurrent before Amazon S3 can perform the associated action.
Implementation
int? noncurrentDays;
Specifies the number of days an object is noncurrent before Amazon S3 can perform the associated action.
int? noncurrentDays;