ReplicationRule class
Specifies which Amazon S3 objects to replicate and where to store the replicas.
Constructors
- ReplicationRule(DeleteMarkerReplication? deleteMarkerReplication, Destination? destination, ExistingObjectReplication? existingObjectReplication, ReplicationRuleFilter? filter, String? iD, String? prefix, int? priority, SourceSelectionCriteria? sourceSelectionCriteria, String? status)
- ReplicationRule.fromXml(XmlElement? xml)
Properties
- deleteMarkerReplication ↔ DeleteMarkerReplication?
-
getter/setter pair
- destination ↔ Destination?
-
getter/setter pair
- existingObjectReplication ↔ ExistingObjectReplication?
-
Type: ExistingObjectReplication data type
getter/setter pair
- filter ↔ ReplicationRuleFilter?
-
A filter that identifies the subset of objects to which the replication rule applies. A Filter must specify exactly one Prefix, Tag, or an And child element.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- iD ↔ String?
-
A unique identifier for the rule. The maximum value is 255 characters.
getter/setter pair
- prefix ↔ String?
-
This member has been deprecated.
getter/setter pair
- priority ↔ int?
-
The priority associated with the rule. If you specify multiple rules in a replication configuration, Amazon S3 prioritizes the rules to prevent conflicts when filtering. If two or more rules identify the same object based on a specified filter, the rule with higher priority takes precedence. For example:
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceSelectionCriteria ↔ SourceSelectionCriteria?
-
A container that describes additional filters for identifying the source objects that you want to replicate. You can choose to enable or disable the replication of these objects. Currently, Amazon S3 supports only the filter that you can specify for objects created with server-side encryption using a customer master key (CMK) stored in AWS Key Management Service (SSE-KMS).
getter/setter pair
- status ↔ String?
-
Specifies whether the rule is enabled.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toXml(
) → XmlNode
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited