ScanRange class
Specifies the byte range of the object to get the records from. A record is processed when its first byte is contained by the range. This parameter is optional, but when specified, it must not be empty. See RFC 2616, Section 14.35.1 about how to specify the start and end of the range.
Constructors
- ScanRange(int? end, int? start)
- ScanRange.fromXml(XmlElement xml)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toXml(
) → XmlNode
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited