Transition class

Specifies when an object transitions to a specified storage class.

Constructors

Transition(DateTime? date, int? days, String? storageClass)
Transition.fromXml(XmlElement? xml)

Properties

date DateTime?
Indicates when objects are transitioned to the specified storage class. The date value must be in ISO 8601 format.
getter/setter pair
days int?
Indicates the number of days after creation when objects are transitioned to the specified storage class. The value must be a positive integer.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageClass String?
The storage class to which you want the object to transition.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toXml() → XmlNode

Operators

operator ==(Object other) bool
The equality operator.
inherited