LifecycleExpiration class
Container for the expiration for the lifecycle of the object.
Constructors
- LifecycleExpiration(DateTime? date, int? days, bool? expiredObjectDeleteMarker)
- LifecycleExpiration.fromXml(XmlElement? xml)
Properties
- date ↔ DateTime?
-
getter/setter pair
- days ↔ int?
-
getter/setter pair
- expiredObjectDeleteMarker ↔ bool?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toXml(
) → XmlNode
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited