NoncurrentVersionExpiration class
Specifies when noncurrent object versions expire. Upon expiration, Amazon S3 permanently deletes the noncurrent object versions.
Constructors
- NoncurrentVersionExpiration(int? noncurrentDays)
- NoncurrentVersionExpiration.fromXml(XmlElement? xml)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- noncurrentDays ↔ int?
-
Specifies the number of days an object is noncurrent before Amazon S3 can perform the associated action.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toXml(
) → XmlNode
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited